@@ -1,7 +1,8 @@
 package NEXT;
-$VERSION = '0.63';
+$VERSION = '0.66';
 use Carp;
 use strict;
+use warnings;
 use overload ();
 
 sub NEXT::ELSEWHERE::ancestors
@@ -42,8 +43,8 @@ sub NEXT::ELSEWHERE::buildAUTOLOAD
         my $caller = (caller($depth))[3];
         my $wanted = $NEXT::AUTOLOAD || $autoload_name;
         undef $NEXT::AUTOLOAD;
-        my ($caller_class, $caller_method) = $caller =~ m{(.*)::(.*)}g;
-        my ($wanted_class, $wanted_method) = $wanted =~ m{(.*)::(.*)}g;
+        my ($caller_class, $caller_method) = do { $caller =~ m{(.*)::(.*)}g };
+        my ($wanted_class, $wanted_method) = do { $wanted =~ m{(.*)::(.*)}g };
         croak "Can't call $wanted from $caller"
             unless $caller_method eq $wanted_method;
 
@@ -78,20 +79,20 @@ sub NEXT::ELSEWHERE::buildAUTOLOAD
             $NEXT::SEEN->{$key,*{$caller}{CODE}}++;
         }
         my $call_method = shift @{$NEXT::NEXT{$key,$wanted_method}};
-        while ($wanted_class =~ /^NEXT\b.*\b(UNSEEN|DISTINCT)\b/
+        while (do { $wanted_class =~ /^NEXT\b.*\b(UNSEEN|DISTINCT)\b/ }
             && defined $call_method
             && $NEXT::SEEN->{$key,$call_method}++) {
             $call_method = shift @{$NEXT::NEXT{$key,$wanted_method}};
         }
         unless (defined $call_method) {
-            return unless $wanted_class =~ /^NEXT:.*:ACTUAL/;
+            return unless do { $wanted_class =~ /^NEXT:.*:ACTUAL/ };
             (local $Carp::CarpLevel)++;
             croak qq(Can't locate object method "$wanted_method" ),
                 qq(via package "$caller_class");
         };
         return $self->$call_method(@_[1..$#_]) if ref $call_method eq 'CODE';
         no strict 'refs';
-        ($wanted_method=${$caller_class."::AUTOLOAD"}) =~ s/.*:://
+        do { ($wanted_method=${$caller_class."::AUTOLOAD"}) =~ s/.*::// }
             if $wanted_method eq 'AUTOLOAD';
         $$call_method = $caller_class."::NEXT::".$wanted_method;
         return $call_method->(@_);
@@ -108,7 +109,8 @@ package NEXT::ACTUAL::DISTINCT;	@ISA = 'NEXT'; NEXT::ELSEWHERE::buildAUTOLOAD();
 package NEXT::UNSEEN::ACTUAL;	@ISA = 'NEXT'; NEXT::ELSEWHERE::buildAUTOLOAD();
 package NEXT::DISTINCT::ACTUAL;	@ISA = 'NEXT'; NEXT::ELSEWHERE::buildAUTOLOAD();
 
-package EVERY;
+package
+    EVERY;
 
 sub EVERY::ELSEWHERE::buildAUTOLOAD {
     my $autoload_name = caller() . '::AUTOLOAD';
@@ -121,7 +123,7 @@ sub EVERY::ELSEWHERE::buildAUTOLOAD {
         my $caller = (caller($depth))[3];
         my $wanted = $EVERY::AUTOLOAD || $autoload_name;
         undef $EVERY::AUTOLOAD;
-        my ($wanted_class, $wanted_method) = $wanted =~ m{(.*)::(.*)}g;
+        my ($wanted_class, $wanted_method) = do { $wanted =~ m{(.*)::(.*)}g };
 
         my $key = ref($self) && overload::Overloaded($self)
             ? overload::StrVal($self) : $self;
@@ -133,7 +135,7 @@ sub EVERY::ELSEWHERE::buildAUTOLOAD {
 
         my @forebears = NEXT::ELSEWHERE::ordered_ancestors ref $self || $self,
                                         $wanted_class;
-        @forebears = reverse @forebears if $wanted_class =~ /\bLAST\b/;
+        @forebears = reverse @forebears if do { $wanted_class =~ /\bLAST\b/ };
         no strict 'refs';
         my %seen;
         my @every = map { my $sub = "${_}::$wanted_method";
@@ -182,7 +184,8 @@ sub EVERY::ELSEWHERE::buildAUTOLOAD {
 }
 
 package EVERY::LAST;   @ISA = 'EVERY';   EVERY::ELSEWHERE::buildAUTOLOAD();
-package EVERY;         @ISA = 'NEXT';    EVERY::ELSEWHERE::buildAUTOLOAD();
+package
+    EVERY;             @ISA = 'NEXT';    EVERY::ELSEWHERE::buildAUTOLOAD();
 
 1;
 
@@ -190,8 +193,7 @@ __END__
 
 =head1 NAME
 
-NEXT.pm - Provide a pseudo-class NEXT (et al) that allows method redispatch
-
+NEXT - Provide a pseudo-class NEXT (et al) that allows method redispatch
 
 =head1 SYNOPSIS
 
@@ -384,7 +386,7 @@ previous example were rewritten:
         E->foo();
 
 then it would print:
-        
+
         called E::foo
         called C::foo
         called A::foo
